@@ -13,6 +13,7 @@
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2018 羽 <Just4test@users.noreply.github.com>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -94,7 +95,7 @@ class Gist(github.GithubObject.CompletableGithubObject):
         """
         :type: dict of string to :class:`github.GistFile.GistFile`
         """
-        self._completeIfNotSet(self._files)
+        self._completeIfNeeded()
         return self._files.value
 
     @property
