@@ -89,7 +89,9 @@ from SourceImport import *
 from Status import *
 from Tag import *
 from Team import *
+from Traffic import *
 from UserKey import *
+from Migration import *
 
 from PaginatedList import *
 from Exceptions import *
